@@ -29,7 +29,7 @@ class Processor:
         self.queue = asyncio.Queue()
         self.result = asyncio.Queue()
         self.logger = Logger()
-        self._ckpt = 0, time.time()
+        self.ckpt_time = 0, time.time()
         if hasattr(self, 'init'):
             ret = self.init()
             if inspect.isawaitable(ret):
@@ -47,12 +47,12 @@ class Processor:
     def _log_stats(self):
         qsize = self.queue.qsize()
         curr_time = time.time()
-        if self._ckpt[0] == 0:
-            self._ckpt = qsize, curr_time
+        if self.ckpt_time[0] == 0:
+            self.ckpt_time = qsize, curr_time
         else:
-            speed = (self._ckpt[0] - qsize) / (curr_time - self._ckpt[1])
-            if curr_time - self._ckpt[1] >= 60:
-                self._ckpt = qsize, curr_time
+            speed = (self.ckpt_time[0] - qsize) / (curr_time - self.ckpt_time[1])
+            if curr_time - self.ckpt_time[1] >= 60:
+                self.ckpt_time = qsize, curr_time
             seconds = int(qsize / speed)
             hours = seconds // 3600
             minutes = (seconds % 3600) // 60
@@ -109,16 +109,17 @@ class Processor:
 
 
 def main():
-    opt = Config(dict(workers=10, forever=False))
+    kwargs = Config(dict(workers=10, forever=False))
     arr = sys.argv[1].split('.')
     module = import_module(arr[0])
     if len(arr) == 1:
-        for k, v in module.__dict__.items():
-            if not k.startswith('__') and isclass(v) and any([x.__module__ == 'processor' and x.__name__ == 'Processor' for x in v.__bases__]):
-                app = v(**opt)
+        items = list(module.__dict__.items())
+        for k, v in items:
+            if isclass(v) and any([x.__module__ == 'processor' and x.__name__ == 'Processor' for x in v.__bases__]):
+                app = v(**kwargs)
                 app.start()
     else:
-        app = getattr(module, arr[1])(**opt)
+        app = getattr(module, arr[1])(**kwargs)
         app.start()
 
 
