@@ -87,8 +87,10 @@ class PageModule(UIModule):
     <li class="page-item disabled"><span class="page-link">{{ total }}项</span></li>
   </ul>
 </nav>''')
-        kwargs.setdefault('size', int(self.handler.get_argument('size', 20)))
-        kwargs.setdefault('page', int(self.handler.get_argument('page', 1)))
+        size = self.handler.get_argument('size', None)
+        page = self.handler.get_argument('page', None)
+        kwargs.setdefault('size', int(size) if size else 20)
+        kwargs.setdefault('page', int(page) if page else 1)
         pages = int(math.ceil(total / kwargs['size']))
         return t.generate(pages=pages, total=total, get_url=self.get_url, **kwargs)
 
