@@ -5,6 +5,7 @@ Author: zhangkai
 Email: zhangkai@cmcm.com
 Last modified: 2018-01-05 11:24:17
 '''
+
 import asyncio
 import os
 import re
@@ -15,11 +16,12 @@ import aredis
 import pymongo
 import pymysql
 import redis
+from bson.son import SON
 from dbutils.pooled_db import PooledDB
 from motor import core
 from motor.docstrings import get_database_doc
 from motor.frameworks import asyncio as asyncio_framework
-from motor.metaprogramming import (AsyncCommand, AsyncRead, DelegateMethod,
+from motor.metaprogramming import (AsyncCommand, DelegateMethod,
                                    coroutine_annotation,
                                    create_class_with_framework,
                                    unwrap_args_session, unwrap_kwargs_session)
@@ -64,11 +66,45 @@ def parse_uri(uri):
     return kwargs
 
 
+class Cursor(pymongo.cursor.Cursor):
+
+    def count(self, with_limit_and_skip=False):
+        cmd = SON([("count", self.__collection.name),
+                   ("query", self.__spec)])
+        if self.__max_time_ms is not None:
+            cmd["maxTimeMS"] = self.__max_time_ms
+        if self.__comment:
+            cmd["comment"] = self.__comment
+
+        if self.__hint is not None:
+            cmd["hint"] = self.__hint
+
+        if with_limit_and_skip:
+            if self.__limit:
+                cmd["limit"] = self.__limit
+            if self.__skip:
+                cmd["skip"] = self.__skip
+
+        return self.__collection._count(
+            cmd, self.__collation, session=self.__session)
+
+
 class Collection(pymongo.collection.Collection):
 
     def find(self, *args, **kwargs):
-        kwargs.update({'no_cursor_timeout': True})
-        return pymongo.cursor.Cursor(self, *args, **kwargs)
+        # kwargs.update({'no_cursor_timeout': True})
+        return Cursor(self, *args, **kwargs)
+
+    def _count(self, cmd, collation=None, session=None):
+        """Internal count helper."""
+        # XXX: "ns missing" checks can be removed when we drop support for
+        # MongoDB 3.0, see SERVER-17051.
+        def _cmd(session, server, sock_info, secondary_ok):
+            return self._count_cmd(
+                session, sock_info, secondary_ok, cmd, collation)
+
+        return self.__database.client._retryable_read(
+            _cmd, self._read_preference_for(session), session)
 
     @property
     def seq_id(self):
@@ -127,7 +163,7 @@ class Mongo(Database):
 
 
 class AgnosticCursor(core.AgnosticCursor):
-    count = AsyncRead()
+    __delegate_class__ = Cursor
 
     @coroutine_annotation
     def to_list(self, length=None):
@@ -136,7 +172,6 @@ class AgnosticCursor(core.AgnosticCursor):
 
 class AgnosticCollection(core.AgnosticCollection):
     __delegate_class__ = Collection
-    count = AsyncRead()
 
     def __init__(self, database, name, codec_options=None,
                  read_preference=None, write_concern=None, read_concern=None,
@@ -164,7 +199,7 @@ class AgnosticCollection(core.AgnosticCollection):
                                 _delegate=self.delegate[name])
 
     def find(self, *args, **kwargs):
-        kwargs.update({'no_cursor_timeout': True})
+        # kwargs.update({'no_cursor_timeout': True})
         cursor = self.delegate.find(*unwrap_args_session(args),
                                     **unwrap_kwargs_session(kwargs))
         cursor_class = create_class_with_framework(
@@ -185,8 +220,6 @@ class AgnosticCollection(core.AgnosticCollection):
 class AgnosticDatabase(core.AgnosticDatabase):
     __delegate_class__ = Database
 
-    authenticate = AsyncCommand()
-    logout = AsyncCommand()
     create_collection = AsyncCommand().wrap(Collection)
     get_collection = DelegateMethod().wrap(Collection)
 
