@@ -155,7 +155,7 @@ class Response:
             return self.body.decode()
 
     def json(self, **kwargs):
-        return DictWrapper(json.loads(self.body, **kwargs))
+        return DictWrapper(json.loads(self.text, **kwargs))
 
     def soup(self, features='html5lib', **kwargs):
         return BeautifulSoup(self.body, features=features, **kwargs)
